# 📜 bluer-journal

📜 `@journal` with command access maintained in a github repo.  

## installation

```bash
pip install bluer-journal
```

# aliases

[@journal](./bluer_journal/docs/aliases/journal.md).

---

> 📜 For the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-journal/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-journal/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-journal/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-journal/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-journal/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-journal/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-journal.svg)](https://pypi.org/project/bluer-journal/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-journal)](https://pypistats.org/packages/bluer-journal)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 📜 [`bluer_journal-5.113.1`](https://github.com/kamangir/bluer-journal).
